# fmcclient

A Go client for the Cisco Firepower Management Center.

## Example

```go
import (
	"context"
	"crypto/tls"
	"fmt"
	"log"
	"net"
	"net/http"
	"net/url"
	"time"

	"idiolink/go/fmcclient"
)

host := "192.0.2.10"
user := "fmcrobot"
pass := "anpassword"
proxy := "socks5://127.0.0.1:8000"

// Configure socks proxy and other transport parameters
tr := &http.Transport{
	TLSClientConfig:       &tls.Config{InsecureSkipVerify: true},
	TLSHandshakeTimeout:   15 * time.Second,
	IdleConnTimeout:       30 * time.Minute,
	ResponseHeaderTimeout: 60 * time.Second,
	ExpectContinueTimeout: 10 * time.Second,
}
var proxyURL *url.URL
proxyURL, err = url.Parse(proxy)
if err != nil {
	log.Fatal(err)
}
if proxyURL != nil {
	tr.Proxy = http.ProxyURL(proxyURL)
}
cl := &http.Client{
	Transport: tr,
	Timeout:   30 * time.Minute,
}

ctx, cancel := context.WithCancel(context.Background())
var fmc *fmcclient.FMC
fmc, err := fmcclient.New(ctx, cl, host, user, pass)
if err != nil {
	log.Fatal(err)
}
if err := fmc.Authenticate(); err != nil {
	log.Println(err)
	return 1
}

var pager fmcclient.Pager
pager, err := fmc.AccessPolicies("Global", 100)
if err != nil {
	return fmt.Errorf("fetch access policy pager: %v", err)
}
acpName := "test"
var acpUUID string
for {
	acps, err := pager.Next()
	if err == fmcclient.EOF {
		break
	}
	if err != nil {
		return fmt.Errorf("fetch access policies: %v", err)
	}
	for _, e := range acps {
		if e.Name == acpName {
			acpUUID = e.Id
			break
		}
	}
}

if acpUUID == "" {
	return fmt.Errorf("find target access policy: no acp with name %v", acpName)
}
```
